@@ -76,7 +76,7 @@ our $idle;    # idle handler
 our $main;    # main coroutine
 our $current; # current coroutine
 
-our $VERSION = 5.11;
+our $VERSION = 5.12;
 
 our @EXPORT = qw(async async_pool cede schedule terminate current unblock_sub);
 our %EXPORT_TAGS = (
@@ -354,7 +354,7 @@ coroutine environment.
 
 =cut
 
-sub _terminate {
+sub _coro_run {
    terminate &{+shift};
 }
 
